@@ -57,7 +57,7 @@ c                   <Pt> is too large so use cylindrical p.s
                 icon=1
             endif
         elseif(ntp .ge. 2) then
-            call ccylps(ntp,  a, icon)
+           call ccylps(ntp,  a, icon)
         else
 c              assume 1 (or 0) pion production in cms
             call c1pion(a, ntp, icon)
@@ -94,8 +94,11 @@ c           avn= 1.1 * roots**0.6
            avn= 1.25 * roots**0.55
        elseif(roots .gt. qcdErg .and. MulLow .eq. 1) then
 c             2.5 is cosmos adjusting factor. (2 is leading)
-          avn = no* exp(sqrt(23./18. * log( (roots/lambda))*2))
-     *          -2.5
+c////////////
+         avn = no* exp(sqrt(23./18. * log( (roots/lambda))*2))
+c    *          -2.5
+c          avn =  1.25 * roots**0.55
+c//////////////
        else
 c           all graphs have been draw with this 
 c           one can fit ua5 non-single diffrective data, but 
@@ -105,7 +108,10 @@ c          avn= 7.2* roots**(2*0.127) - 8.0  ! 2.5 for adj. 2 is leading
 c               too strong power.  very good at root s = 53 
 c          avn= 6.9* roots**(2*0.127) - 8.0  ! 2.5 for adj. 2 is leadingc 
 c               finally adopeted
-           avn= 7.1* roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
+c/////////
+ccc///           avn= 7.1* roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
+          avn =  1.25 * roots**0.55
+c/////////
 c           avn= 6.8 * roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
        endif
 c           at roots > 50 GeV, we may try a QCD prediction like
