@@ -98,14 +98,15 @@ c                  should be rotated later
 c               sample recoil target  and set it in Rtgpatr
 c               the same note as above.
               call cslp(Tgpatr, xtmin, xtmax, Rtgpatr)
+c                       next should not be used.
 c                    some dirty trick to make the strange evnet less
 c                    (may not be needed)
 c                  make target pt colinear with projectile Pt
 c                  while keeping the magnitude as it is
-              c2=Rtgpatr.fm.p(1)**2 + Rtgpatr.fm.p(2)**2
-              den=sqrt(( Rpjtatr.fm.p(1)**2 +  Rpjtatr.fm.p(2)**2)/c2 )
-              Rtgpatr.fm.p(1) = Rpjtatr.fm.p(1)/den
-              Rtgpatr.fm.p(2) = Rpjtatr.fm.p(2)/den
+c              c2=Rtgpatr.fm.p(1)**2 + Rtgpatr.fm.p(2)**2
+c              den=sqrt(( Rpjtatr.fm.p(1)**2 +  Rpjtatr.fm.p(2)**2)/c2 )
+c              Rtgpatr.fm.p(1) = Rpjtatr.fm.p(1)/den
+c              Rtgpatr.fm.p(2) = Rpjtatr.fm.p(2)/den
 c     If the following two call's were omitted and equivalent ones
 c     were placed inside 'cslp', 
 c         Absoft compile fials to compile it; it shows
@@ -508,6 +509,9 @@ c                  uniform random number should be between
 c                  umin and umax
 
             call rndc(u)
+c////////////////
+c            u = u**2.5
+c//////////////
             u=(umax-umin)*u + umin
             i=u*nx +1
             if(pj.code .eq. knuc) then
