@@ -116,14 +116,14 @@ c     0 (within the computational accuracy).
 c
       if(id .eq. 2) then
 c            output typical quantities.
-c        write(*, *) 
-c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
-c     *  aTrack.p.code,    !  ptcl code.  integer*2.
-c     *  aTrack.p.charge,  !  charge,  integer*2 
+        write(*, *) 
+     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
+     *  aTrack.p.code,    !  ptcl code.  integer*2.
+     *  aTrack.p.charge,  !  charge,  integer*2 
 c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
 c                        !  if TimeStructure is F, nonsense.
-c     *  sngl(aTrack.p.fm.e),  ! total energy in GeV.
-c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y), !  x, y in m
+     *  sngl(aTrack.p.fm.e),  ! total energy in GeV.
+     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y)  !  x, y in m
 c     *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.y),  ! direc. cos.y
 c     *  sngl(aTrack.vec.w.z),  ! direc. cos.z
@@ -348,3 +348,4 @@ c             'col' or 'decay'
       end
 
       
+     
