@@ -203,6 +203,9 @@ c             sample interaction length
             collkgram=-mfp*log(u)
          endif
       endif
+      if(.not.Freec .and. Zfirst.pos.depth .eq.0.) then
+         collkgram = 0.
+      endif
 c/////////////////
 c      write(*,*) ' ActivM=',ActiveMdl, ' code=',ka,
 c     *        ' E=',ek, ' mfp=',mfp/10., ' Useint=',UseInt2
